#
# spec file for package doctest
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           doctest
Version:        2.4.6
Release:        bp154.1.21
Summary:        Single-header testing framework
License:        MIT
URL:            http://bit.ly/doctest-docs
Source0:        https://github.com/onqtam/doctest/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-build-with-GCC-11.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
C++98/C++11 single-header testing framework for unit tests and TDD.

%package        devel
Summary:        Single-header testing framework

%description    devel
C++98/C++11 single-header testing framework for unit tests and TDD.

%prep
%autosetup -p1

%build
# fix cmake module path
sed -i 's|lib/cmake|%{_lib}/cmake|g' CMakeLists.txt

%cmake
%cmake_build

%install
%cmake_install

# creates support file for pkg-config
mkdir -p %{buildroot}/%{_libdir}/pkgconfig
tee %{buildroot}/%{_libdir}/pkgconfig/doctest.pc << "EOF"
prefix=%{_prefix}
exec_prefix=${prefix}
libdir=${exec_prefix}/%{_lib}
includedir=${prefix}/include

Name:           doctest
Description: Single-header testing framework
Version:        %{version}
Libs:
Cflags: -I${includedir}/doctest
EOF

%files devel
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{_includedir}/doctest
%{_libdir}/cmake/doctest
%{_libdir}/pkgconfig/doctest.pc

%changelog
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 compatibility fix:
  * 0001-Fix-build-with-GCC-11.patch
* Mon Mar 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.6
  Fixed bugs:
  * REQUIRE does not compile when operator== in different
    namespace #443
  * Using templated operator== inside TEST_CASE changes deduced
    types of forwarding references #399
  Closed issues:
  * CMake doesn't link package #483
  * Get list of registered test-case names #479
  * Can't compile with glibc master (future 2.34): SIGSTKSZ is
    no longer a constant #473
  * INFO does not compile when used like a function call #469
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.5
  Closed issues:
  * Use of std::atomic can slow down multithreaded tests #452
  * Stack buffer overflow in String constructor #460
  Merged pull requests:
  * Fix compilation on case-sensitive filesystems #463
  * Use function-like macros for prefixless macro names #462
  * Implement a multi lane atomic for assertion counts
- Update to version 2.4.4
  * combine the same tests for different build configurations from
    multiple shared objects without having symbol clashes #436
* Tue Dec 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.2
  Closed issues:
  * DOCTEST_CHECK_THROWS_WITH_AS fails to work with dependant
    exception type #447
  * log contexts for failures in JUnit reporter #441
  * Test runner thread initialization #435
  * CHECK_EQ with enum values #276
  Merged pull requests:
  * Add MAIN_PROJECT check for test option #445
  * log contexts for failures in JUnit reporter #442
* Wed Nov  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.1
  * Support for unit tests with Open MPI as a new extension header.
  * Added default printers for enums.
* Thu Sep 24 2020 Martin Hauke <mardnh@gmx.de>
- Enable arm builds. The package builds fine on aarch64 systems.
* Mon Aug 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v2.4.0)
